/*
 *  Macro di root per convertire i dati da formato ascii a formato root.
 *  Lanciare come:
 *
 *  shell> root -l
 *  root[0] .L ASCII2TTree.C
 *  root[1] ASCII2TTree("meas_600305_C_p001.dat","meas_600305_C_p001.root")
 */


void ASCII2TTree(const char* inputFileName, const char* outputFileName)
{
    cout<<"Converting "<<inputFileName<<" into "<<outputFileName<<endl;

    // apre il file di input con l'oggetto ifstream
    // che appartiene alle librerie standard C++
    ifstream inFile;
    inFile.open(inputFileName);

    // apre il file di output in formato root
    TFile* outFile = new TFile(outputFileName,"RECREATE");
    // crea un TTree che verra' poi scritto in outFile.
    // al tree viene assegnato un nome (datatree) e una descrizione.
    TTree* tree = new TTree("datatree","data from my experiment");

    // crea le variabili in cui mettere il contenuto del file di input
    // e le assegna al TTree di output
    int time, A1, pos1, A2, pos2;
    tree->Branch("Time",&time,"Time/I");
    tree->Branch("A1",&A1,"A1/I");
    tree->Branch("Pos1",&pos1,"Pos1/I");
    tree->Branch("A2",&A2,"A2/I");
    tree->Branch("Pos2",&pos2,"Pos2/I");

    // legge il file riga per riga e riempie il TTree.
    while(1) {
        inFile>>time>>A1>>pos1>>A2>>pos2;
        if(!inFile.good()) break;
        tree->Fill();
    }

    // scrive il numero di eventi (= numero righe del file) nel TTree.
    cout<<"Number of entries: "<<tree->GetEntries()<<endl;

    // scrive il tree nel file e chiude il file
    tree->Write();
    outFile->Close();
}
