/*
 *  Macro di root per analizzare i dati.
 *  Lanciare come:
 *
 *  shell> root -l
 *  root[0] .L Analyze.C
 *  root[1] Analyze("nomeDelFile.root")
 */

void Analyze(const char* fileName)
{

    // apre file prende il TTree di nome "datatree" dal file
    TFile* file = new TFile(fileName);
    TTree* tree = (TTree*)file->Get("datatree");

    // stampa il numero di eventi
    Long64_t nentries = tree->GetEntries();
    cout<<"The tree contains "<<nentries<<" entries"<<endl;

    // setta indirizzi delle variabili di interesse
    int A1,A2;
    tree->SetBranchAddress("A1",&A1);
    tree->SetBranchAddress("A2",&A2);

    // crea 2 istogrammi vuoti, quello totale e quello relativo
    // al solo gamma da 2615 keV da usare per la calibrazione 
    TH1D* hAmpl1 = new TH1D("hAmpl1","ADC Histogram of channel 1",1000,0,10000); 
    TH1D* hAmpl2 = new TH1D("hAmpl2","ADC Ch1 2614.5 keV",30,9300,9460); 

    // loopa sugli eventi contenuti nel tree e riempi gli istogrammi
    for(Long64_t entry = 0; entry < nentries; entry++) {
        tree->GetEntry(entry);
        if(A1 > 0) {
            hAmpl1->Fill(A1);
        }
        if(A1>9300 && A1<9460) {
            hAmpl2->Fill(A1);
        }
    }


    // mostra istogramma totale
    TCanvas* c1 = new TCanvas();
    hAmpl1->Draw();

    // mostra istogramma del picco a 2615 keV
    TCanvas* c2 = new TCanvas();
    hAmpl2->Draw();

    // fitta con gaussiana il picco e stima coeff. di calibrazione
    TF1* fitFunc = new TF1("fitFunc","gaus");
    hAmpl2->Fit(fitFunc);
    double mean = fitFunc->GetParameter(1);
    double meanErr = fitFunc->GetParError(1);
    cout<<"Mean: "<<mean<<"+/-"<<meanErr<<endl;
    double calCoeff = 2614.5/mean;

    // reloopa sugli eventi e riempi istogramma in energia
    TH1D* hEnergy1 = new TH1D("hEnergy1","Energy spectrum of channel 1",3000,0,3000);

    for(Long64_t entry = 0; entry < nentries; entry++) {
        tree->GetEntry(entry);
        if(A1>0) {
            hEnergy1->Fill(A1*calCoeff);
        }

    }

    // mostra istogramma energia, setta nomi agli assi e 
    // salva su file pdf
    TCanvas* c3 = new TCanvas();
    hEnergy1->GetXaxis()->SetTitle("Energy [keV]");
    hEnergy1->GetYaxis()->SetTitle("counts / 1 keV");
    hEnergy1->Draw();
    c3->SaveAs("spectrum_ch1.pdf");
}
